@@ -38,3 +38,9 @@ test_that("can set multiple same-named headers", {
   expect_true(another)
 })
 
+test_that("response properly sets cookies with multiple options", {
+  res <- PlumberResponse$new()
+  res$setCookie("abc", "two words", http=TRUE, secure=TRUE, same_site="None")
+  head <- res$toResponse()$headers
+  expect_equal(head[["Set-Cookie"]], "abc=two%20words; HttpOnly; Secure; SameSite=None")
+})
